/*
  Filename:	main.c
  Author:	Ron Burkey
  Legal:	I, Ron Burkey, am placing this file in the public domain.
  Purpose:     	Some simple usage of pthreads.
  Mod history:	2008-04-08 RSB	Created.
  		2008-05-05 RSB	Ross Johnson (maintainer of the pthreads-win32
				project) has pointed out several ways in which
				I made using pthreads-win32 more complex than
				it needed to be.  Naturally, those 
				simplifications have been made here.  Thanks,
				Ross!

  This test program simply creates two threads,and lets them fight over
  stdout.
*/

#include <stdio.h>
#include <stdlib.h>
#include <pthread.h>
#include <time.h>

#ifdef WIN32
#include <windows.h>
#define sleep(x) Sleep(1000*(x))
#endif 

static void *
Thread1 (void *arg)
{
  int Count;
   
  for (Count = 0; Count < 10; Count++)
    {
      printf ("1111111111\n");
      sleep (1);
    }
    
  printf ("Now, the lines of 1111111111 will not be printed any longer.\n");

  return (NULL);
}

static void *
Thread2 (void *arg)
{
  int Count;
 
  for (Count = 0; Count < 20; Count++)
    {
      printf ("2222222222\n");
      sleep (1);
    }
    
  printf ("Now, the lines of 2222222222 will not be printed any longer.\n");

  return (NULL);
}

int
main (void)
{
  int i, Count;
  pthread_t ThreadStruct1, ThreadStruct2;

#ifdef PTW32_STATIC_LIB
  // You wouldn't need this if I had compiled pthreads_w32 as a DLL.
  pthread_win32_process_attach_np ();
#endif  
  
  printf (
    "You should see lines of 1111111111, 222222222, 3333333333,\n"
    "printed once per second.\n");
  
  i = pthread_create (&ThreadStruct1, NULL, &Thread1, NULL);
  if (i != 0)
    {
      printf ("Creation of first thread failed!\n");
      return (1);
    }
  i = pthread_create (&ThreadStruct2, NULL, &Thread2, NULL);
  if (i != 0)
    {
      printf ("Creation of second thread failed!\n");
      return (1);
    }
  for (Count = 0; Count < 30; Count++)
    {
      printf ("3333333333\n");
      sleep (1);
    }

#ifdef PTW32_STATIC_LIB
  // You wouldn't need this if I had compiled pthreads_w32 as a DLL.
  pthread_win32_process_detach_np ();
#endif  

  printf ("Now we are all done.  Goodbye!\n");

  return (0);
}

