#!/bin/bash
# This script is to provide a workaround for the fact that the version of 
# odcctools we're trying to use builds but does not build *correctly* with
# gcc 4.3.  The idea of the workaround is that if you have gcc 4.3 as your
# main compiler, you could also have 4.2, 4.1, or 4.0 installed as an 
# alternate version.  So this script selects a version of gcc to be used 
# to build odcctools, among those gcc versions which are installed, and
# which it can find.  If the CC environment variable is already set, it 
# will be prioritized over plain gcc.

if $CC -v &>/dev/null
then
  if ! $CC -v 2>&1 | grep -c "gcc version 4[.]3" &>/dev/null
  then
    echo "$CC"
    exit 0
  fi
fi

if gcc -v 2>&1 | grep -c "gcc version 4[.]3" &>/dev/null
then
  # Yes, the native compiler is 4.3.  The CORRECT way to install alternate
  # versions of gcc is to allow selection via the -V command-line switch:
  # for example, "gcc -V 4.2".  Ubuntu is properly set up for this.  
  # OpenSUSE is not.  Fedora doesn't offer alternate 4.x versions from 
  # their package repository at all.
  for n in "gcc -V 4.2" "gcc -V 4.1" "gcc -V 4.0" "gcc-4.2" "gcc-4.1" "gcc-4.0"
  do
    if $n -v &>/dev/null
    then
      echo "$n"
      exit 0
    fi
  done
  echo "gcc-none"
  exit 1
fi

# The native compiler isn't 4.3, so we just use it as-is.
echo "gcc"
exit 0

